# Homeserver Sample Configuration File

Below is a sample homeserver configuration file. The homeserver configuration file 
can be tweaked to change the behaviour of your homeserver. A restart of the server is 
generally required to apply any changes made to this file.

Note that the contents below are *not* intended to be copied and used as the basis for
a real homeserver.yaml. Instead, if you are starting from scratch, please generate
a fresh config using Synapse by following the instructions in
[Installation](../../setup/installation.md).

Documentation for all configuration options can be found in the
[Configuration Manual](./config_documentation.md).

```yaml
{{#include ../../sample_config.yaml}}
```
